function [ P ] = puissance( presence, rayonnement, appareil )
%Cette fonction renvoie une courbe annuelle de puissance consomme par un
%appareil lectrique


dependant_presence=appareil(1);
dependant_rayonnement=appareil(2);
rayonnement_limite=appareil(3);
puissance_moyenne=appareil(4);          % Puissance moyenne consomme par l'appariel lectrique [W]
sigma_puissance_moyenne=appareil(5);    % Ecart-type de la puissance consomme [W]
puissance_veille=appareil(6);           % Puissance de l'appareil en mode veille [W]
duree_moyenne=appareil(7);              % Dure moyenne de chaque utilisation de l'appariel [min]
sigma_duree=appareil(8);                % Ecart-type de la dure de chaque utilisation [min] 
frequence_moyenne=appareil(9);          % Frquence moyenne d'utilisation [j]
sigma_frequence_moyenne=appareil(10);     % Sigma frquencemoyenne d'utilisation
heure_start_moyenne=appareil(11);         % Heure moyenne de mise en route de l'appareil 
sigma_heure_start=appareil(12);           % Ecart-type de l'heure de mise en marche de l'appareil.



% Fonction alatoire permettant de "tirer au sort" les jours de l'anne o
% l'appareil sera utilis.
appareil_jours =round(normrnd(frequence_moyenne,sigma_frequence_moyenne));
while (appareil_jours(size(appareil_jours,2)))<365.25
   appareil_jours=[appareil_jours appareil_jours(size(appareil_jours,2))+round(normrnd(frequence_moyenne,sigma_frequence_moyenne))];
end

% Fonction alatoire permettant de "tirer au sort" les heures de dmarrage
% de l'appareil pour les jours o il est utilis ainsi que les dures d'utilisation.
for n = 1:size(appareil_jours,2)
   appareil_heures_start(n)=normrnd(heure_start_moyenne,sigma_heure_start);
   appareil_durees(n)=normrnd(duree_moyenne,sigma_duree);
end
 
% Fonction permettant de retourner, minute par minute, si l'appareil est
% utilis ou non (0 ou 1)
m=1;
appareil_on(1)=0;
for n = 2:365.25*24*60
   if n<appareil_jours(m)*24*60+appareil_heures_start(m)*60 && appareil_on(n-1)==0
       appareil_on(n)=0;
   elseif n<appareil_jours(m)*24*60+appareil_heures_start(m)*60+appareil_durees(m)
       appareil_on(n)=1;
   else
       appareil_on(n)=0;
       m=m+1;
   end
end

% Fonction permettant, pour chaque moment o l'appreil est en marche, d'y
% attribuer une puissance (fonction alatoire)
P=0;
Pappareil(1)=0;
for n = 2:365.25*24*60
   if appareil_on(n)==1 && appareil_on(n-1)==0
       P=normrnd(puissance_moyenne,sigma_puissance_moyenne);
   end
   P_appareil(n)=P*appareil_on(n);
   if P_appareil(n)==0
    P_appareil(n)=puissance_veille;
   end
end

% Fonction permettant de faire tomber la puissane  la puissance de veille si personne n'est  la maison et que l'utilisation
% de l'appareil ne se fait que si une personne est prsente.
if dependant_presence==1
    for n = 2:365.25*24*60
       if presence(n)==0
           P_appareil(n)=puissance_veille;
       end
    end
end

% Fonction permettant de faire tomber la puissane  la puissance de veille
% si l'utilisation de l'appareil dpend du rayonnement et que celui-ci est
% suffisant (clairage)
if dependant_rayonnement==1
    for n = 2:365.25*24*60
       if rayonnement(n)>rayonnement_limite
           P_appareil(n)=puissance_veille;
       end
    end
end

% On retourne la puissance en fonction du temps
P=P_appareil;
end

